@@ -3,5 +3,5 @@ from django.conf.urls.defaults import *  # NOQA
 
 urlpatterns = patterns(
     '',
-    url(r'^contact/', include('contact_form.urls')),
+    url(r'^', include('contact_form.urls')),
 )
